import { Component, Input, Output, EventEmitter } from '@angular/core';
import { FormBuilder, Validators } from '@angular/forms';
import { Router } from '@angular/router';
import { ObjectService } from '../../utilities/object.service';
export var UNDEFINED_NAME = 'SearchFormComponent_name_unspecified';
export var DEFAULT_TARGET = './search';
var SearchFormComponent = (function () {
    function SearchFormComponent(formBuilder, router, objectService) {
        this.formBuilder = formBuilder;
        this.router = router;
        this.objectService = objectService;
        this.configuredOptions = {
            name: UNDEFINED_NAME,
            target: DEFAULT_TARGET
        };
        this.searchForm = this.formBuilder.group({
            terms: [this.terms, Validators.required]
        });
        this.searchedTerms = new EventEmitter();
    }
    SearchFormComponent.prototype.ngOnInit = function () {
        if (!!this.options) {
            this.configuredOptions = this.objectService.shallowCopy(this.configuredOptions, this.options);
        }
    };
    SearchFormComponent.prototype.search = function () {
        if (!this.searchForm.valid) {
            return;
        }
        this.searchedTerms.emit(this.terms);
        this.router.navigate([this.configuredOptions.target], { queryParams: { q: this.terms } });
    };
    return SearchFormComponent;
}());
export { SearchFormComponent };
SearchFormComponent.decorators = [
    { type: Component, args: [{
                selector: 'app-search-form',
                template: "<div class=\"row\"> <b>Search for stuff</b> <form [formGroup]=\"searchForm\" (ngSubmit)=\"search()\"> <div class=\"col-md-10\"> <input formControlName=\"terms\" [(ngModel)]=\"terms\" type=\"text\" placeholder=\"Separate search terms by ,\" /> </div> <div class=\"col-md-2\"> <button type=\"submit\">Search</button> </div> </form> </div> ",
                styles: ["b { font-weight: normal; } .search-form { background-color: red; } "]
            },] },
];
/** @nocollapse */
SearchFormComponent.ctorParameters = function () { return [
    { type: FormBuilder, },
    { type: Router, },
    { type: ObjectService, },
]; };
SearchFormComponent.propDecorators = {
    'options': [{ type: Input },],
    'searchedTerms': [{ type: Output },],
};
//# sourceMappingURL=search-form.component.js.map